@@ -23,7 +23,6 @@ class DPageDef
 		$pagedef = DPageDef::GetInstance();
 		$type = $dinfo->Get(DInfo::FLD_View);
 		$pid = $dinfo->Get(DInfo::FLD_PID);
-
 		return $pagedef->_pageDef[$type][$pid];
 	}
 
@@ -56,6 +55,7 @@ class DPageDef
 			new DTblMap(['security:fileAccessControl', 'fileAccessControl' ], 'S_SEC_FILE'),
 			new DTblMap(['security:perClientConnLimit', 'perClientConnLimit' ], 'S_SEC_CONN'),
 			new DTblMap(['security:CGIRLimit', 'CGIRLimit' ], 'S_SEC_CGI'),
+            new DTblMap(['security', ''], 'S_SEC_BUBBLEWRAP'),
 			new DTblMap(['security:accessDenyDir', 'accessDenyDir' ], 'S_SEC_DENY'),
 			new DTblMap(['security:accessControl', 'accessControl' ], 'A_SEC_AC'),
             new DTblMap('lsrecaptcha', 'S_SEC_RECAP'),
@@ -94,6 +94,7 @@ class DPageDef
                     new DTblMap(['security:accessControl','accessControl'], 'A_SEC_AC'),
                     new DTblMap(['security:realmList:*realm','*realm$name'], 'V_REALM_FILE'),
                     new DTblMap('lsrecaptcha', 'VT_SEC_RECAP'),
+                    new DTblMap(['security',''], 'VT_SEC_BUBBLEWRAP'),
                     new DTblMap(['extProcessorList:*extProcessor','*extprocessor$name'], 'A_EXT_SEL'),
                     new DTblMap(['contextList:*context', '*context$uri'], 'VT_CTX_SEL'),
                     new DTblMap('rewrite',
@@ -164,10 +165,11 @@ class DPageDef
 
 		$id = 'sec';
 		$page = new DPage($id, DMsg::UIStr('tab_sec'), new DTblMap('',
-				[new DTblMap('fileAccessControl', 'S_SEC_FILE'),
+                    [new DTblMap('fileAccessControl', 'S_SEC_FILE'),
 						new DTblMap('perClientConnLimit', 'S_SEC_CONN'),
 						new DTblMap('CGIRLimit', 'S_SEC_CGI'),
-                        new DTblMap('lsrecaptcha', 'S_SEC_RECAP'), ////////// maybe wrong
+                        new DTblMap('lsrecaptcha', 'S_SEC_RECAP'), 
+                        'S_SEC_BUBBLEWRAP',
 						new DTblMap('accessDenyDir', 'S_SEC_DENY'),
 						new DTblMap('accessControl', 'A_SEC_AC')]));
 		$this->_pageDef['serv'][$id] = $page;
